# django-naivedatetimefield
![build status](https://api.travis-ci.org/camflan/django-naivedatetimefield.svg?branch=master)


NaiveDateTimeField offers the ability to store a naive timestamp, useful for baking in a local timestamp.



## Contributors
- [Camron Flanders](https://github.com/camflan)
- [Alex Hill](https://github.com/AlexHill)
- [Lincoln Puzey](https://github.com/LincolnPuzey)
